import { jsxs, jsx, Fragment as Fragment$1 } from "@builder.io/qwik/jsx-runtime";
import { TARGET } from "../../constants/target.qwik.mjs";
import { handleABTestingSync } from "../../helpers/ab-tests.qwik.mjs";
import { getDefaultCanTrack } from "../../helpers/canTrack.qwik.mjs";
import { ContentComponent } from "../content/content.qwik.mjs";
import { InlinedScript } from "../inlined-script.qwik.mjs";
import { InlinedStyles } from "../inlined-styles.qwik.mjs";
import { checkShouldRenderVariants, getUpdateCookieAndStylesScript, getVariants, getInitVariantsFnsScriptString } from "./helpers.qwik.mjs";
import { component$, useStore, useComputed$, Fragment } from "@builder.io/qwik";
const ContentVariants = component$((props) => {
  const state = useStore({
    shouldRenderVariants: checkShouldRenderVariants({
      canTrack: getDefaultCanTrack(props.canTrack),
      content: props.content
    })
  });
  const updateCookieAndStylesScriptStr = useComputed$(() => {
    var _a;
    return getUpdateCookieAndStylesScript(getVariants(props.content).map((value) => ({
      id: value.testVariationId,
      testRatio: value.testRatio
    })), ((_a = props.content) == null ? void 0 : _a.id) || "");
  });
  const hideVariantsStyleString = useComputed$(() => {
    return getVariants(props.content).map((value) => `.variant-${value.testVariationId} { display: none; } `).join("");
  });
  const defaultContent = useComputed$(() => {
    var _a;
    return state.shouldRenderVariants ? {
      ...props.content,
      testVariationId: (_a = props.content) == null ? void 0 : _a.id
    } : handleABTestingSync({
      item: props.content,
      canTrack: getDefaultCanTrack(props.canTrack)
    });
  });
  return /* @__PURE__ */ jsxs(Fragment, {
    children: [
      !props.isNestedRender && TARGET !== "reactNative" ? /* @__PURE__ */ jsx(InlinedScript, {
        id: "builderio-init-variants-fns",
        scriptStr: getInitVariantsFnsScriptString(),
        nonce: props.nonce || ""
      }) : null,
      state.shouldRenderVariants ? /* @__PURE__ */ jsxs(Fragment$1, {
        children: [
          /* @__PURE__ */ jsx(InlinedStyles, {
            id: "builderio-variants",
            styles: hideVariantsStyleString.value,
            nonce: props.nonce || ""
          }),
          /* @__PURE__ */ jsx(InlinedScript, {
            id: "builderio-variants-visibility",
            scriptStr: updateCookieAndStylesScriptStr.value,
            nonce: props.nonce || ""
          }),
          (getVariants(props.content) || []).map((variant) => {
            return /* @__PURE__ */ jsx(ContentComponent, {
              isNestedRender: props.isNestedRender,
              nonce: props.nonce,
              content: variant,
              showContent: false,
              model: props.model,
              data: props.data,
              context: props.context,
              apiKey: props.apiKey,
              apiVersion: props.apiVersion,
              customComponents: props.customComponents,
              linkComponent: props.linkComponent,
              canTrack: props.canTrack,
              locale: props.locale,
              enrich: props.enrich,
              isSsrAbTest: state.shouldRenderVariants,
              blocksWrapper: props.blocksWrapper,
              blocksWrapperProps: props.blocksWrapperProps,
              contentWrapper: props.contentWrapper,
              contentWrapperProps: props.contentWrapperProps,
              trustedHosts: props.trustedHosts
            }, variant.testVariationId);
          })
        ]
      }) : null,
      /* @__PURE__ */ jsx(ContentComponent, {
        nonce: props.nonce,
        isNestedRender: props.isNestedRender,
        content: defaultContent.value,
        showContent: true,
        model: props.model,
        data: props.data,
        context: props.context,
        apiKey: props.apiKey,
        apiVersion: props.apiVersion,
        customComponents: props.customComponents,
        linkComponent: props.linkComponent,
        canTrack: props.canTrack,
        locale: props.locale,
        enrich: props.enrich,
        isSsrAbTest: state.shouldRenderVariants,
        blocksWrapper: props.blocksWrapper,
        blocksWrapperProps: props.blocksWrapperProps,
        contentWrapper: props.contentWrapper,
        contentWrapperProps: props.contentWrapperProps,
        trustedHosts: props.trustedHosts
      })
    ]
  });
});
export {
  ContentVariants,
  ContentVariants as default
};
