import { jsx, Fragment } from "@builder.io/qwik/jsx-runtime";
import builderContext from "../../../context/builder.context.qwik.mjs";
import { evaluate } from "../../../functions/evaluate/evaluate.qwik.mjs";
import { fastClone } from "../../../functions/fast-clone.qwik.mjs";
import { fetchOneEntry } from "../../../functions/get-content/index.qwik.mjs";
import { isBrowser } from "../../../functions/is-browser.qwik.mjs";
import { isEditing } from "../../../functions/is-editing.qwik.mjs";
import { isPreviewing } from "../../../functions/is-previewing.qwik.mjs";
import { createRegisterComponentMessage } from "../../../functions/register-component.qwik.mjs";
import { _track } from "../../../functions/track/index.qwik.mjs";
import { getInteractionPropertiesForEvent } from "../../../functions/track/interaction.qwik.mjs";
import { getDefaultCanTrack } from "../../../helpers/canTrack.qwik.mjs";
import { createEditorListener } from "../../../helpers/subscribe-to-editor.qwik.mjs";
import { registerInsertMenu, setupBrowserForEditing } from "../../../scripts/init-editing.qwik.mjs";
import { triggerAnimation } from "../../block/animator.qwik.mjs";
import { getWrapperClassName } from "./styles.helpers.qwik.mjs";
import { component$, useComputed$, useSignal, useStore, useOn, $, useContextProvider, useTask$, Slot } from "@builder.io/qwik";
const mergeNewRootState = function mergeNewRootState2(props, state, showContentProps, elementRef, newData) {
  var _a, _b;
  const combinedState = {
    ...props.builderContextSignal.rootState,
    ...newData
  };
  if (props.builderContextSignal.rootSetState) {
    (_b = (_a = props.builderContextSignal).rootSetState) == null ? void 0 : _b.call(_a, combinedState);
  } else {
    props.builderContextSignal.rootState = combinedState;
  }
};
const mergeNewContent = function mergeNewContent2(props, state, showContentProps, elementRef, newContent) {
  var _a, _b, _c, _d, _e;
  const newContentValue = {
    ...props.builderContextSignal.content,
    ...newContent,
    data: {
      ...(_a = props.builderContextSignal.content) == null ? void 0 : _a.data,
      ...newContent == null ? void 0 : newContent.data
    },
    meta: {
      ...(_b = props.builderContextSignal.content) == null ? void 0 : _b.meta,
      ...newContent == null ? void 0 : newContent.meta,
      breakpoints: ((_c = newContent == null ? void 0 : newContent.meta) == null ? void 0 : _c.breakpoints) || ((_e = (_d = props.builderContextSignal.content) == null ? void 0 : _d.meta) == null ? void 0 : _e.breakpoints)
    }
  };
  props.builderContextSignal.content = newContentValue;
};
const processMessage = function processMessage2(props, state, showContentProps, elementRef, event) {
  return createEditorListener({
    model: props.model,
    trustedHosts: props.trustedHosts,
    callbacks: {
      configureSdk: (messageContent) => {
        var _a;
        const { breakpoints, contentId } = messageContent;
        if (!contentId || contentId !== ((_a = props.builderContextSignal.content) == null ? void 0 : _a.id)) {
          return;
        }
        if (breakpoints) {
          mergeNewContent(props, state, showContentProps, elementRef, {
            meta: {
              breakpoints
            }
          });
        }
      },
      animation: (animation) => {
        triggerAnimation(animation);
      },
      contentUpdate: (newContent) => {
        mergeNewContent(props, state, showContentProps, elementRef, newContent);
      }
    }
  })(event);
};
const onClick = function onClick2(props, state, showContentProps, elementRef, event) {
  var _a, _b;
  if (props.builderContextSignal.content) {
    const variationId = (_a = props.builderContextSignal.content) == null ? void 0 : _a.testVariationId;
    const contentId = (_b = props.builderContextSignal.content) == null ? void 0 : _b.id;
    _track({
      type: "click",
      canTrack: getDefaultCanTrack(props.canTrack),
      contentId,
      apiKey: props.apiKey,
      variationId: variationId !== contentId ? variationId : void 0,
      ...getInteractionPropertiesForEvent(event),
      unique: !state.clicked
    });
  }
  if (!state.clicked) {
    state.clicked = true;
  }
};
const runHttpRequests = function runHttpRequests2(props, state, showContentProps, elementRef) {
  var _a, _b;
  const requests = ((_b = (_a = props.builderContextSignal.content) == null ? void 0 : _a.data) == null ? void 0 : _b.httpRequests) ?? {};
  Object.entries(requests).forEach(([key, url]) => {
    if (!url)
      return;
    if (state.httpReqsPending[key])
      return;
    if (state.httpReqsData[key] && !isEditing())
      return;
    state.httpReqsPending[key] = true;
    const evaluatedUrl = url.replace(/{{([^}]+)}}/g, (_match, group) => String(evaluate({
      code: group,
      context: props.context || {},
      localState: void 0,
      rootState: props.builderContextSignal.rootState,
      rootSetState: props.builderContextSignal.rootSetState,
      enableCache: true
    })));
    fetch(evaluatedUrl).then((response) => response.json()).then((json) => {
      mergeNewRootState(props, state, showContentProps, elementRef, {
        [key]: json
      });
      state.httpReqsData[key] = true;
    }).catch((err) => {
      console.error("error fetching dynamic data", url, err);
    }).finally(() => {
      state.httpReqsPending[key] = false;
    });
  });
};
const emitStateUpdate = function emitStateUpdate2(props, state, showContentProps, elementRef) {
  if (isEditing()) {
    window.dispatchEvent(new CustomEvent("builder:component:stateChange", {
      detail: {
        state: fastClone(props.builderContextSignal.rootState),
        ref: {
          name: props.model
        }
      }
    }));
  }
};
const EnableEditor = component$((props) => {
  var _a, _b, _c, _d, _e;
  const showContentProps = useComputed$(() => {
    return props.showContent ? {} : {
      hidden: true,
      "aria-hidden": true
    };
  });
  const elementRef = useSignal();
  const state = useStore({
    ContentWrapper: props.contentWrapper || "div",
    clicked: false,
    httpReqsData: {},
    httpReqsPending: {}
  }, {
    deep: true
  });
  useOn("initeditingbldr", $((event, element) => {
    window.addEventListener("message", processMessage.bind(null, props, state, showContentProps, elementRef));
    registerInsertMenu();
    setupBrowserForEditing({
      ...props.locale ? {
        locale: props.locale
      } : {},
      ...props.enrich ? {
        enrich: props.enrich
      } : {},
      ...props.trustedHosts ? {
        trustedHosts: props.trustedHosts
      } : {}
    });
    Object.values(props.builderContextSignal.componentInfos).forEach((registeredComponent) => {
      var _a2;
      const message = createRegisterComponentMessage(registeredComponent);
      (_a2 = window.parent) == null ? void 0 : _a2.postMessage(message, "*");
    });
    window.addEventListener("builder:component:stateChangeListenerActivated", emitStateUpdate.bind(null, props, state, showContentProps, elementRef));
  }));
  useOn("initpreviewingbldr", $((event, element) => {
    const searchParams = new URL(location.href).searchParams;
    const searchParamPreviewModel = searchParams.get("builder.preview");
    const searchParamPreviewId = searchParams.get(`builder.overrides.${searchParamPreviewModel}`);
    const previewApiKey = searchParams.get("apiKey") || searchParams.get("builder.space");
    if (searchParamPreviewModel === props.model && previewApiKey === props.apiKey && (!props.content || searchParamPreviewId === props.content.id)) {
      fetchOneEntry({
        model: props.model,
        apiKey: props.apiKey,
        apiVersion: props.builderContextSignal.apiVersion
      }).then((content) => {
        if (content) {
          mergeNewContent(props, state, showContentProps, elementRef, content);
        }
      });
    }
  }));
  useOn("qvisible", $((event, element) => {
    var _a2, _b2, _c2, _d2;
    if (isBrowser()) {
      if (isEditing()) {
        if (element) {
          element.dispatchEvent(new CustomEvent("initeditingbldr"));
        }
      }
      const shouldTrackImpression = ((_a2 = element.attributes.getNamedItem("shouldTrack")) == null ? void 0 : _a2.value) === "true";
      if (shouldTrackImpression) {
        const variationId = (_b2 = element.attributes.getNamedItem("variationId")) == null ? void 0 : _b2.value;
        const contentId = (_c2 = element.attributes.getNamedItem("contentId")) == null ? void 0 : _c2.value;
        const apiKeyProp = (_d2 = element.attributes.getNamedItem("apiKey")) == null ? void 0 : _d2.value;
        _track({
          type: "impression",
          canTrack: true,
          contentId,
          apiKey: apiKeyProp,
          variationId: variationId !== contentId ? variationId : void 0
        });
      }
      if (isPreviewing() && !isEditing()) {
        if (element) {
          element.dispatchEvent(new CustomEvent("initpreviewingbldr"));
        }
      }
    }
  }));
  useContextProvider(builderContext, props.builderContextSignal);
  useTask$(() => {
    runHttpRequests(props, state, showContentProps, elementRef);
    emitStateUpdate(props);
  });
  useTask$(({ track }) => {
    track(() => props.content);
    if (props.content) {
      mergeNewContent(props, state, showContentProps, elementRef, props.content);
    }
  });
  useTask$(({ track }) => {
    track(() => props.builderContextSignal.rootState);
    emitStateUpdate(props);
  });
  useTask$(({ track }) => {
    track(() => props.data);
    if (props.data) {
      mergeNewRootState(props, state, showContentProps, elementRef, props.data);
    }
  });
  useTask$(({ track }) => {
    track(() => props.locale);
    if (props.locale) {
      mergeNewRootState(props, state, showContentProps, elementRef, {
        locale: props.locale
      });
    }
  });
  return /* @__PURE__ */ jsx(Fragment, {
    children: props.builderContextSignal.content ? /* @__PURE__ */ jsx(state.ContentWrapper, {
      apiKey: props.apiKey,
      contentId: (_a = props.builderContextSignal.content) == null ? void 0 : _a.id,
      variationId: (_b = props.builderContextSignal.content) == null ? void 0 : _b.testVariationId,
      shouldTrack: String(props.builderContextSignal.content && getDefaultCanTrack(props.canTrack)),
      ref: elementRef,
      onClick$: $((event) => onClick(props, state, showContentProps, elementRef, event)),
      "builder-content-id": (_c = props.builderContextSignal.content) == null ? void 0 : _c.id,
      "builder-model": props.model,
      className: getWrapperClassName(((_d = props.content) == null ? void 0 : _d.testVariationId) || ((_e = props.content) == null ? void 0 : _e.id)),
      ...showContentProps.value,
      ...props.contentWrapperProps,
      children: /* @__PURE__ */ jsx(Slot, {})
    }) : null
  });
});
export {
  EnableEditor,
  EnableEditor as default,
  emitStateUpdate,
  mergeNewContent,
  mergeNewRootState,
  onClick,
  processMessage,
  runHttpRequests
};
