import { logger } from "../../helpers/logger.qwik.mjs";
import { chooseBrowserOrServerEval } from "./choose-eval.qwik.mjs";
import { parseCode, getBuilderGlobals } from "./helpers.qwik.mjs";
const DISABLE_CACHE = true;
const _EvalCache = class _EvalCache2 {
  static getCacheKey(args) {
    return JSON.stringify({
      ...args,
      // replace the event with a random number to break cache
      // thats because we can't serialize the event object due to circular refs in DOM node refs.
      event: args.event ? Math.random() : void 0
    });
  }
  static getCachedValue(key) {
    const cachedVal = _EvalCache2.cache.get(key);
    return cachedVal;
  }
  static setCachedValue(key, value) {
    if (_EvalCache2.cache.size > 20) {
      _EvalCache2.cache.delete(_EvalCache2.cache.keys().next().value);
    }
    _EvalCache2.cache.set(key, {
      value
    });
  }
};
_EvalCache.cacheLimit = 20;
_EvalCache.cache = /* @__PURE__ */ new Map();
let EvalCache = _EvalCache;
function evaluate({ code, context, localState, rootState, rootSetState, event, isExpression = true, enableCache }) {
  if (code === "") {
    return void 0;
  }
  const args = {
    code: parseCode(code, {
      isExpression
    }),
    builder: getBuilderGlobals(),
    context,
    event,
    rootSetState,
    rootState,
    localState
  };
  if (enableCache && !DISABLE_CACHE) {
    const cacheKey = EvalCache.getCacheKey(args);
    const cachedValue = EvalCache.getCachedValue(cacheKey);
    if (cachedValue) {
      return cachedValue.value;
    }
  }
  try {
    const newEval = chooseBrowserOrServerEval(args);
    if (enableCache) {
      const cacheKey = EvalCache.getCacheKey(args);
      EvalCache.setCachedValue(cacheKey, newEval);
    }
    return newEval;
  } catch (e) {
    logger.error("Failed code evaluation: " + e.message, {
      code
    });
    return void 0;
  }
}
export {
  evaluate
};
