"use strict";
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const jsxRuntime = require("@builder.io/qwik/jsx-runtime");
const blocks = require("../../components/blocks/blocks.qwik.cjs");
const helpers = require("./helpers.qwik.cjs");
const qwik = require("@builder.io/qwik");
const getAccordionTitleClassName = function getAccordionTitleClassName2(props, state, onlyOneAtATime, accordionStyles, accordionTitleStyles, openGridItemOrder, accordionDetailStyles, index) {
  return `builder-accordion-title builder-accordion-title-${state.open.includes(index) ? "open" : "closed"}`;
};
const getAccordionDetailClassName = function getAccordionDetailClassName2(props, state, onlyOneAtATime, accordionStyles, accordionTitleStyles, openGridItemOrder, accordionDetailStyles, index) {
  return `builder-accordion-detail builder-accordion-detail-${state.open.includes(index) ? "open" : "closed"}`;
};
const onClick = function onClick2(props, state, onlyOneAtATime, accordionStyles, accordionTitleStyles, openGridItemOrder, accordionDetailStyles, index) {
  if (state.open.includes(index)) {
    state.open = onlyOneAtATime.value ? [] : state.open.filter((item) => item !== index);
  } else {
    state.open = onlyOneAtATime.value ? [
      index
    ] : state.open.concat(index);
  }
};
const Accordion = qwik.component$((props) => {
  const state = qwik.useStore({
    open: []
  });
  const onlyOneAtATime = qwik.useComputed$(() => {
    return Boolean(props.grid || props.oneAtATime);
  });
  const accordionStyles = qwik.useComputed$(() => {
    const styles = {
      display: "flex",
      alignItems: "stretch",
      flexDirection: "column",
      ...props.grid && {
        flexDirection: "row",
        alignItems: "flex-start",
        flexWrap: "wrap"
      }
    };
    return styles;
  });
  const accordionTitleStyles = qwik.useComputed$(() => {
    const shared = {
      display: "flex",
      flexDirection: "column"
    };
    const styles = {
      ...shared,
      alignItems: "stretch",
      cursor: "pointer"
    };
    return Object.fromEntries(Object.entries(styles).filter(([_, value]) => value !== void 0));
  });
  const openGridItemOrder = qwik.useComputed$(() => {
    let itemOrder = null;
    const getOpenGridItemPosition = props.grid && state.open.length;
    if (getOpenGridItemPosition && document) {
      const openItemIndex = state.open[0];
      const openItem = document.querySelector(`.builder-accordion-title[data-index="${openItemIndex}"]`);
      let subjectItem = openItem;
      itemOrder = openItemIndex;
      if (subjectItem) {
        let prevItemRect = subjectItem.getBoundingClientRect();
        while (subjectItem = subjectItem && subjectItem.nextElementSibling) {
          if (subjectItem) {
            if (subjectItem.classList.contains("builder-accordion-detail")) {
              continue;
            }
            const subjectItemRect = subjectItem.getBoundingClientRect();
            if (subjectItemRect.left > prevItemRect.left) {
              const index = parseInt(subjectItem.getAttribute("data-index") || "", 10);
              if (!isNaN(index)) {
                prevItemRect = subjectItemRect;
                itemOrder = index;
              }
            } else {
              break;
            }
          }
        }
      }
    }
    if (typeof itemOrder === "number") {
      itemOrder = itemOrder + 1;
    }
    return itemOrder;
  });
  const accordionDetailStyles = qwik.useComputed$(() => {
    const styles = {
      ...{
        order: typeof openGridItemOrder.value === "number" ? openGridItemOrder.value : void 0
      },
      ...props.grid && {
        width: "100%"
      }
    };
    return Object.fromEntries(Object.entries(styles).filter(([_, value]) => value !== void 0));
  });
  return /* @__PURE__ */ jsxRuntime.jsx("div", {
    class: "builder-accordion",
    style: accordionStyles.value,
    children: (props.items || []).map((item, index) => {
      return /* @__PURE__ */ jsxRuntime.jsxs(qwik.Fragment, {
        children: [
          /* @__PURE__ */ jsxRuntime.jsx("div", {
            class: getAccordionTitleClassName(props, state, onlyOneAtATime, accordionStyles, accordionTitleStyles, openGridItemOrder, accordionDetailStyles, index),
            style: {
              ...accordionTitleStyles.value,
              width: props.grid ? props.gridRowWidth : void 0,
              ...{
                order: openGridItemOrder.value !== null ? helpers.convertOrderNumberToString(index) : helpers.convertOrderNumberToString(index + 1)
              }
            },
            "data-index": index,
            onClick$: qwik.$((event) => onClick(props, state, onlyOneAtATime, accordionStyles, accordionTitleStyles, openGridItemOrder, accordionDetailStyles, index)),
            children: /* @__PURE__ */ jsxRuntime.jsx(blocks.Blocks, {
              blocks: item.title,
              path: `items.${index}.title`,
              parent: props.builderBlock.id,
              context: props.builderContext,
              registeredComponents: props.builderComponents,
              linkComponent: props.builderLinkComponent
            })
          }),
          state.open.includes(index) ? /* @__PURE__ */ jsxRuntime.jsx("div", {
            class: getAccordionDetailClassName(props, state, onlyOneAtATime, accordionStyles, accordionTitleStyles, openGridItemOrder, accordionDetailStyles, index),
            style: accordionDetailStyles.value,
            children: /* @__PURE__ */ jsxRuntime.jsx(blocks.Blocks, {
              blocks: item.detail,
              path: `items.${index}.detail`,
              parent: props.builderBlock.id,
              context: props.builderContext,
              registeredComponents: props.builderComponents,
              linkComponent: props.builderLinkComponent
            })
          }) : null
        ]
      });
    })
  });
});
exports.Accordion = Accordion;
exports.default = Accordion;
exports.getAccordionDetailClassName = getAccordionDetailClassName;
exports.getAccordionTitleClassName = getAccordionTitleClassName;
exports.onClick = onClick;
