"use strict";
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const jsxRuntime = require("@builder.io/qwik/jsx-runtime");
const image_helpers = require("./image.helpers.qwik.cjs");
const qwik = require("@builder.io/qwik");
const Image = qwik.component$((props) => {
  var _a, _b, _c, _d, _e, _f;
  qwik.useStylesScoped$(STYLES);
  const srcSetToUse = qwik.useComputed$(() => {
    var _a2;
    const imageToUse = props.image || props.src;
    const url = imageToUse;
    if (!url || // We can auto add srcset for cdn.builder.io and shopify
    // images, otherwise you can supply this prop manually
    !(url.match(/builder\.io/) || url.match(/cdn\.shopify\.com/))) {
      return props.srcset;
    }
    if (props.noWebp) {
      return void 0;
    }
    if (props.srcset && ((_a2 = props.image) == null ? void 0 : _a2.includes("builder.io/api/v1/image"))) {
      if (!props.srcset.includes(props.image.split("?")[0])) {
        console.debug("Removed given srcset");
        return image_helpers.getSrcSet(url);
      }
    } else if (props.image && !props.srcset) {
      return image_helpers.getSrcSet(url);
    }
    return image_helpers.getSrcSet(url);
  });
  const webpSrcSet = qwik.useComputed$(() => {
    var _a2;
    if (((_a2 = srcSetToUse.value) == null ? void 0 : _a2.match(/builder\.io/)) && !props.noWebp) {
      return srcSetToUse.value.replace(/\?/g, "?format=webp&");
    } else {
      return "";
    }
  });
  const aspectRatioCss = qwik.useComputed$(() => {
    const aspectRatioStyles = {
      position: "absolute",
      height: "100%",
      width: "100%",
      left: "0px",
      top: "0px"
    };
    const out = props.aspectRatio ? aspectRatioStyles : void 0;
    return out;
  });
  qwik.useVisibleTask$(() => {
  });
  return /* @__PURE__ */ jsxRuntime.jsxs(qwik.Fragment, {
    children: [
      /* @__PURE__ */ jsxRuntime.jsxs("picture", {
        children: [
          webpSrcSet.value ? /* @__PURE__ */ jsxRuntime.jsx("source", {
            type: "image/webp",
            srcset: webpSrcSet.value
          }) : null,
          /* @__PURE__ */ jsxRuntime.jsx("img", {
            loading: props.highPriority ? "eager" : "lazy",
            fetchPriority: props.highPriority ? "high" : "auto",
            alt: props.altText,
            role: props.altText ? void 0 : "presentation",
            style: {
              objectPosition: props.backgroundPosition || "center",
              objectFit: props.backgroundSize || "cover",
              ...aspectRatioCss.value
            },
            class: "builder-image" + (props.className ? " " + props.className : "") + " img-Image",
            src: props.image,
            srcset: srcSetToUse.value,
            sizes: props.sizes
          })
        ]
      }),
      props.aspectRatio && !(((_b = (_a = props.builderBlock) == null ? void 0 : _a.children) == null ? void 0 : _b.length) && props.fitContent) ? /* @__PURE__ */ jsxRuntime.jsx("div", {
        class: "builder-image-sizer div-Image",
        style: {
          paddingTop: props.aspectRatio * 100 + "%"
        }
      }) : null,
      ((_d = (_c = props.builderBlock) == null ? void 0 : _c.children) == null ? void 0 : _d.length) && props.fitContent ? /* @__PURE__ */ jsxRuntime.jsx(qwik.Slot, {}) : null,
      !props.fitContent && ((_f = (_e = props.builderBlock) == null ? void 0 : _e.children) == null ? void 0 : _f.length) ? /* @__PURE__ */ jsxRuntime.jsx("div", {
        class: "div-Image-2",
        children: /* @__PURE__ */ jsxRuntime.jsx(qwik.Slot, {})
      }) : null
    ]
  });
});
const STYLES = `
.img-Image {
  opacity: 1;
  transition: opacity 0.2s ease-in-out;
}
.div-Image {
  width: 100%;
  pointer-events: none;
  font-size: 0;
}
.div-Image-2 {
  display: flex;
  flex-direction: column;
  align-items: stretch;
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}
`;
exports.Image = Image;
exports.STYLES = STYLES;
exports.default = Image;
