"use strict";
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const jsxRuntime = require("@builder.io/qwik/jsx-runtime");
const builder_context = require("../../../context/builder.context.qwik.cjs");
const evaluate = require("../../../functions/evaluate/evaluate.qwik.cjs");
const fastClone = require("../../../functions/fast-clone.qwik.cjs");
const index = require("../../../functions/get-content/index.qwik.cjs");
const isBrowser = require("../../../functions/is-browser.qwik.cjs");
const isEditing = require("../../../functions/is-editing.qwik.cjs");
const isPreviewing = require("../../../functions/is-previewing.qwik.cjs");
const registerComponent = require("../../../functions/register-component.qwik.cjs");
const index$1 = require("../../../functions/track/index.qwik.cjs");
const interaction = require("../../../functions/track/interaction.qwik.cjs");
const canTrack = require("../../../helpers/canTrack.qwik.cjs");
const subscribeToEditor = require("../../../helpers/subscribe-to-editor.qwik.cjs");
const initEditing = require("../../../scripts/init-editing.qwik.cjs");
const animator = require("../../block/animator.qwik.cjs");
const styles_helpers = require("./styles.helpers.qwik.cjs");
const qwik = require("@builder.io/qwik");
const mergeNewRootState = function mergeNewRootState2(props, state, showContentProps, elementRef, newData) {
  var _a, _b;
  const combinedState = {
    ...props.builderContextSignal.rootState,
    ...newData
  };
  if (props.builderContextSignal.rootSetState) {
    (_b = (_a = props.builderContextSignal).rootSetState) == null ? void 0 : _b.call(_a, combinedState);
  } else {
    props.builderContextSignal.rootState = combinedState;
  }
};
const mergeNewContent = function mergeNewContent2(props, state, showContentProps, elementRef, newContent) {
  var _a, _b, _c, _d, _e;
  const newContentValue = {
    ...props.builderContextSignal.content,
    ...newContent,
    data: {
      ...(_a = props.builderContextSignal.content) == null ? void 0 : _a.data,
      ...newContent == null ? void 0 : newContent.data
    },
    meta: {
      ...(_b = props.builderContextSignal.content) == null ? void 0 : _b.meta,
      ...newContent == null ? void 0 : newContent.meta,
      breakpoints: ((_c = newContent == null ? void 0 : newContent.meta) == null ? void 0 : _c.breakpoints) || ((_e = (_d = props.builderContextSignal.content) == null ? void 0 : _d.meta) == null ? void 0 : _e.breakpoints)
    }
  };
  props.builderContextSignal.content = newContentValue;
};
const processMessage = function processMessage2(props, state, showContentProps, elementRef, event) {
  return subscribeToEditor.createEditorListener({
    model: props.model,
    trustedHosts: props.trustedHosts,
    callbacks: {
      configureSdk: (messageContent) => {
        var _a;
        const { breakpoints, contentId } = messageContent;
        if (!contentId || contentId !== ((_a = props.builderContextSignal.content) == null ? void 0 : _a.id)) {
          return;
        }
        if (breakpoints) {
          mergeNewContent(props, state, showContentProps, elementRef, {
            meta: {
              breakpoints
            }
          });
        }
      },
      animation: (animation) => {
        animator.triggerAnimation(animation);
      },
      contentUpdate: (newContent) => {
        mergeNewContent(props, state, showContentProps, elementRef, newContent);
      }
    }
  })(event);
};
const onClick = function onClick2(props, state, showContentProps, elementRef, event) {
  var _a, _b;
  if (props.builderContextSignal.content) {
    const variationId = (_a = props.builderContextSignal.content) == null ? void 0 : _a.testVariationId;
    const contentId = (_b = props.builderContextSignal.content) == null ? void 0 : _b.id;
    index$1._track({
      type: "click",
      canTrack: canTrack.getDefaultCanTrack(props.canTrack),
      contentId,
      apiKey: props.apiKey,
      variationId: variationId !== contentId ? variationId : void 0,
      ...interaction.getInteractionPropertiesForEvent(event),
      unique: !state.clicked
    });
  }
  if (!state.clicked) {
    state.clicked = true;
  }
};
const runHttpRequests = function runHttpRequests2(props, state, showContentProps, elementRef) {
  var _a, _b;
  const requests = ((_b = (_a = props.builderContextSignal.content) == null ? void 0 : _a.data) == null ? void 0 : _b.httpRequests) ?? {};
  Object.entries(requests).forEach(([key, url]) => {
    if (!url)
      return;
    if (state.httpReqsPending[key])
      return;
    if (state.httpReqsData[key] && !isEditing.isEditing())
      return;
    state.httpReqsPending[key] = true;
    const evaluatedUrl = url.replace(/{{([^}]+)}}/g, (_match, group) => String(evaluate.evaluate({
      code: group,
      context: props.context || {},
      localState: void 0,
      rootState: props.builderContextSignal.rootState,
      rootSetState: props.builderContextSignal.rootSetState,
      enableCache: true
    })));
    fetch(evaluatedUrl).then((response) => response.json()).then((json) => {
      mergeNewRootState(props, state, showContentProps, elementRef, {
        [key]: json
      });
      state.httpReqsData[key] = true;
    }).catch((err) => {
      console.error("error fetching dynamic data", url, err);
    }).finally(() => {
      state.httpReqsPending[key] = false;
    });
  });
};
const emitStateUpdate = function emitStateUpdate2(props, state, showContentProps, elementRef) {
  if (isEditing.isEditing()) {
    window.dispatchEvent(new CustomEvent("builder:component:stateChange", {
      detail: {
        state: fastClone.fastClone(props.builderContextSignal.rootState),
        ref: {
          name: props.model
        }
      }
    }));
  }
};
const EnableEditor = qwik.component$((props) => {
  var _a, _b, _c, _d, _e;
  const showContentProps = qwik.useComputed$(() => {
    return props.showContent ? {} : {
      hidden: true,
      "aria-hidden": true
    };
  });
  const elementRef = qwik.useSignal();
  const state = qwik.useStore({
    ContentWrapper: props.contentWrapper || "div",
    clicked: false,
    httpReqsData: {},
    httpReqsPending: {}
  }, {
    deep: true
  });
  qwik.useOn("initeditingbldr", qwik.$((event, element) => {
    window.addEventListener("message", processMessage.bind(null, props, state, showContentProps, elementRef));
    initEditing.registerInsertMenu();
    initEditing.setupBrowserForEditing({
      ...props.locale ? {
        locale: props.locale
      } : {},
      ...props.enrich ? {
        enrich: props.enrich
      } : {},
      ...props.trustedHosts ? {
        trustedHosts: props.trustedHosts
      } : {}
    });
    Object.values(props.builderContextSignal.componentInfos).forEach((registeredComponent) => {
      var _a2;
      const message = registerComponent.createRegisterComponentMessage(registeredComponent);
      (_a2 = window.parent) == null ? void 0 : _a2.postMessage(message, "*");
    });
    window.addEventListener("builder:component:stateChangeListenerActivated", emitStateUpdate.bind(null, props, state, showContentProps, elementRef));
  }));
  qwik.useOn("initpreviewingbldr", qwik.$((event, element) => {
    const searchParams = new URL(location.href).searchParams;
    const searchParamPreviewModel = searchParams.get("builder.preview");
    const searchParamPreviewId = searchParams.get(`builder.overrides.${searchParamPreviewModel}`);
    const previewApiKey = searchParams.get("apiKey") || searchParams.get("builder.space");
    if (searchParamPreviewModel === props.model && previewApiKey === props.apiKey && (!props.content || searchParamPreviewId === props.content.id)) {
      index.fetchOneEntry({
        model: props.model,
        apiKey: props.apiKey,
        apiVersion: props.builderContextSignal.apiVersion
      }).then((content) => {
        if (content) {
          mergeNewContent(props, state, showContentProps, elementRef, content);
        }
      });
    }
  }));
  qwik.useOn("qvisible", qwik.$((event, element) => {
    var _a2, _b2, _c2, _d2;
    if (isBrowser.isBrowser()) {
      if (isEditing.isEditing()) {
        if (element) {
          element.dispatchEvent(new CustomEvent("initeditingbldr"));
        }
      }
      const shouldTrackImpression = ((_a2 = element.attributes.getNamedItem("shouldTrack")) == null ? void 0 : _a2.value) === "true";
      if (shouldTrackImpression) {
        const variationId = (_b2 = element.attributes.getNamedItem("variationId")) == null ? void 0 : _b2.value;
        const contentId = (_c2 = element.attributes.getNamedItem("contentId")) == null ? void 0 : _c2.value;
        const apiKeyProp = (_d2 = element.attributes.getNamedItem("apiKey")) == null ? void 0 : _d2.value;
        index$1._track({
          type: "impression",
          canTrack: true,
          contentId,
          apiKey: apiKeyProp,
          variationId: variationId !== contentId ? variationId : void 0
        });
      }
      if (isPreviewing.isPreviewing() && !isEditing.isEditing()) {
        if (element) {
          element.dispatchEvent(new CustomEvent("initpreviewingbldr"));
        }
      }
    }
  }));
  qwik.useContextProvider(builder_context, props.builderContextSignal);
  qwik.useTask$(() => {
    runHttpRequests(props, state, showContentProps, elementRef);
    emitStateUpdate(props);
  });
  qwik.useTask$(({ track }) => {
    track(() => props.content);
    if (props.content) {
      mergeNewContent(props, state, showContentProps, elementRef, props.content);
    }
  });
  qwik.useTask$(({ track }) => {
    track(() => props.builderContextSignal.rootState);
    emitStateUpdate(props);
  });
  qwik.useTask$(({ track }) => {
    track(() => props.data);
    if (props.data) {
      mergeNewRootState(props, state, showContentProps, elementRef, props.data);
    }
  });
  qwik.useTask$(({ track }) => {
    track(() => props.locale);
    if (props.locale) {
      mergeNewRootState(props, state, showContentProps, elementRef, {
        locale: props.locale
      });
    }
  });
  return /* @__PURE__ */ jsxRuntime.jsx(jsxRuntime.Fragment, {
    children: props.builderContextSignal.content ? /* @__PURE__ */ jsxRuntime.jsx(state.ContentWrapper, {
      apiKey: props.apiKey,
      contentId: (_a = props.builderContextSignal.content) == null ? void 0 : _a.id,
      variationId: (_b = props.builderContextSignal.content) == null ? void 0 : _b.testVariationId,
      shouldTrack: String(props.builderContextSignal.content && canTrack.getDefaultCanTrack(props.canTrack)),
      ref: elementRef,
      onClick$: qwik.$((event) => onClick(props, state, showContentProps, elementRef, event)),
      "builder-content-id": (_c = props.builderContextSignal.content) == null ? void 0 : _c.id,
      "builder-model": props.model,
      className: styles_helpers.getWrapperClassName(((_d = props.content) == null ? void 0 : _d.testVariationId) || ((_e = props.content) == null ? void 0 : _e.id)),
      ...showContentProps.value,
      ...props.contentWrapperProps,
      children: /* @__PURE__ */ jsxRuntime.jsx(qwik.Slot, {})
    }) : null
  });
});
exports.EnableEditor = EnableEditor;
exports.default = EnableEditor;
exports.emitStateUpdate = emitStateUpdate;
exports.mergeNewContent = mergeNewContent;
exports.mergeNewRootState = mergeNewRootState;
exports.onClick = onClick;
exports.processMessage = processMessage;
exports.runHttpRequests = runHttpRequests;
