"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const logger = require("../../../helpers/logger.qwik.cjs");
const helpers = require("../helpers.qwik.cjs");
const acornInterpreter = require("./acorn-interpreter.qwik.cjs");
function patchInterpreter() {
  const originalGetProperty = acornInterpreter.prototype.getProperty;
  const originalSetProperty = acornInterpreter.prototype.setProperty;
  function newGetProperty(obj, name) {
    if (obj == null || !obj._connected) {
      return originalGetProperty.call(this, obj, name);
    }
    const value = obj._connected[name];
    if (Array.isArray(value)) {
      return this.nativeToPseudo(value);
    }
    if (typeof value === "object") {
      return this.createConnectedObject(value);
    }
    return value;
  }
  function newSetProperty(obj, name, value, opt_descriptor) {
    if (obj == null || !obj._connected) {
      return originalSetProperty.call(this, obj, name, value, opt_descriptor);
    }
    obj._connected[name] = this.pseudoToNative(value);
  }
  const getKeys = [];
  const setKeys = [];
  for (const key of Object.keys(acornInterpreter.prototype)) {
    if (acornInterpreter.prototype[key] === originalGetProperty) {
      getKeys.push(key);
    }
    if (acornInterpreter.prototype[key] === originalSetProperty) {
      setKeys.push(key);
    }
  }
  for (const key of getKeys) {
    acornInterpreter.prototype[key] = newGetProperty;
  }
  for (const key of setKeys) {
    acornInterpreter.prototype[key] = newSetProperty;
  }
  acornInterpreter.prototype.createConnectedObject = function(obj) {
    const connectedObject = this.createObject(this.OBJECT);
    connectedObject._connected = obj;
    return connectedObject;
  };
}
patchInterpreter();
const processCode = (code) => {
  return code.replace(/^.*?function main\(\)/, `
var __awaiter = function (e, t, n, r) {return r()},
__generator = function (e, t) { return t() };
function main()`).replace(/\?\./g, ".");
};
const getJSONValName = (val) => val + "JSON";
const runInEdge = ({ builder, context, event, rootState, localState, rootSetState, code }) => {
  const state = helpers.flattenState({
    rootState,
    localState,
    rootSetState
  });
  const properties = helpers.getFunctionArguments({
    builder,
    context,
    event,
    state
  });
  const prependedCode = properties.map(([key]) => {
    const jsonValName = getJSONValName(key);
    if (key === "state") {
      return ``;
    }
    return `var ${key} = ${jsonValName} === undefined ? undefined : JSON.parse(${jsonValName});`;
  }).join("\n");
  const cleanedCode = processCode(code);
  if (cleanedCode === "") {
    logger.logger.warn("Skipping evaluation of empty code block.");
    return;
  }
  const transformed = `
function theFunction() {
  ${prependedCode}

  ${cleanedCode}
}
theFunction();
`;
  const initFunc = function(interpreter, globalObject) {
    properties.forEach(([key, val]) => {
      if (key === "state") {
        interpreter.setProperty(globalObject, key, interpreter.createConnectedObject(val), interpreter.READONLY_DESCRIPTOR);
      } else {
        const jsonVal = JSON.stringify(val);
        interpreter.setProperty(globalObject, getJSONValName(key), jsonVal);
      }
    });
  };
  const myInterpreter = new acornInterpreter(transformed, initFunc);
  myInterpreter.run();
  const output = myInterpreter.pseudoToNative(myInterpreter.value);
  return output;
};
exports.runInEdge = runInEdge;
