import { isBrowser } from "../functions/is-browser.qwik.mjs";
import { isFromTrustedHost } from "../functions/is-from-trusted-host.qwik.mjs";
import { setupBrowserForEditing } from "../scripts/init-editing.qwik.mjs";
import { logger } from "./logger.qwik.mjs";
const createEditorListener = ({ model, trustedHosts, callbacks }) => {
  return (event) => {
    if (!isFromTrustedHost(trustedHosts, event)) {
      return;
    }
    const { data } = event;
    if (data) {
      switch (data.type) {
        case "builder.configureSdk": {
          callbacks.configureSdk(data.data);
          break;
        }
        case "builder.triggerAnimation": {
          callbacks.animation(data.data);
          break;
        }
        case "builder.contentUpdate": {
          const messageContent = data.data;
          const key = messageContent.key || messageContent.alias || messageContent.entry || messageContent.modelName;
          const contentData = messageContent.data;
          if (key === model) {
            callbacks.contentUpdate(contentData);
          }
          break;
        }
      }
    }
  };
};
const subscribeToEditor = (model, callback, options) => {
  if (!isBrowser) {
    logger.warn("`subscribeToEditor` only works in the browser. It currently seems to be running on the server.");
    return () => {
    };
  }
  setupBrowserForEditing();
  const listener = createEditorListener({
    callbacks: {
      contentUpdate: callback,
      animation: () => {
      },
      configureSdk: () => {
      }
    },
    model,
    trustedHosts: options == null ? void 0 : options.trustedHosts
  });
  window.addEventListener("message", listener);
  return () => {
    window.removeEventListener("message", listener);
  };
};
export {
  createEditorListener,
  subscribeToEditor
};
