import { jsx, Fragment } from "@builder.io/qwik/jsx-runtime";
import { getSizesForBreakpoints, getMaxWidthQueryForSize } from "../../../constants/device-sizes.qwik.mjs";
import { camelToKebabCase } from "../../../functions/camel-to-kebab-case.qwik.mjs";
import { createCssClass } from "../../../helpers/css.qwik.mjs";
import { checkIsDefined } from "../../../helpers/nullable.qwik.mjs";
import { InlinedStyles } from "../../inlined-styles.qwik.mjs";
import { component$, useComputed$ } from "@builder.io/qwik";
const BlockStyles = component$((props) => {
  const canShowBlock = useComputed$(() => {
    const processedBlock = props.block;
    if (checkIsDefined(processedBlock.hide)) {
      return !processedBlock.hide;
    }
    if (checkIsDefined(processedBlock.show)) {
      return processedBlock.show;
    }
    return true;
  });
  const css = useComputed$(() => {
    var _a, _b, _c;
    const processedBlock = props.block;
    const styles = processedBlock.responsiveStyles;
    const content = props.context.content;
    const sizesWithUpdatedBreakpoints = getSizesForBreakpoints(((_a = content == null ? void 0 : content.meta) == null ? void 0 : _a.breakpoints) || {});
    const largeStyles = styles == null ? void 0 : styles.large;
    const mediumStyles = styles == null ? void 0 : styles.medium;
    const smallStyles = styles == null ? void 0 : styles.small;
    const className = processedBlock.id;
    if (!className) {
      return "";
    }
    const largeStylesClass = largeStyles ? createCssClass({
      className,
      styles: largeStyles
    }) : "";
    const mediumStylesClass = mediumStyles ? createCssClass({
      className,
      styles: mediumStyles,
      mediaQuery: getMaxWidthQueryForSize("medium", sizesWithUpdatedBreakpoints)
    }) : "";
    const smallStylesClass = smallStyles ? createCssClass({
      className,
      styles: smallStyles,
      mediaQuery: getMaxWidthQueryForSize("small", sizesWithUpdatedBreakpoints)
    }) : "";
    const hoverAnimation = processedBlock.animations && processedBlock.animations.find((item) => item.trigger === "hover");
    let hoverStylesClass = "";
    if (hoverAnimation) {
      const hoverStyles = ((_c = (_b = hoverAnimation.steps) == null ? void 0 : _b[1]) == null ? void 0 : _c.styles) || {};
      hoverStylesClass = createCssClass({
        className: `${className}:hover`,
        styles: {
          ...hoverStyles,
          transition: `all ${hoverAnimation.duration}s ${camelToKebabCase(hoverAnimation.easing)}`,
          transitionDelay: hoverAnimation.delay ? `${hoverAnimation.delay}s` : "0s"
        }
      }) || "";
    }
    return [
      largeStylesClass,
      mediumStylesClass,
      smallStylesClass,
      hoverStylesClass
    ].join(" ");
  });
  return /* @__PURE__ */ jsx(Fragment, {
    children: css.value && canShowBlock.value ? /* @__PURE__ */ jsx(InlinedStyles, {
      id: "builderio-block",
      styles: css.value,
      nonce: props.context.nonce
    }) : null
  });
});
export {
  BlockStyles,
  BlockStyles as default
};
